 Reahl is a web application framework that allows a Python programmer to work in 
 terms of useful abstractions - using a single programming language.

 Reahl-mailutil is a simple library for sending emails (optionally from ReST 
 sources).
